@@ -1,5 +1,5 @@
 pathanalysis <-
-function(corMatrix, resp.col, colinearity = FALSE)
+function(corMatrix, resp.col, collinearity = FALSE)
 {
    stopifnot(is.matrix(corMatrix))
    if (resp.col < 1 || resp.col > nrow(corMatrix))
@@ -8,7 +8,7 @@ function(corMatrix, resp.col, colinearity = FALSE)
       rownames(corMatrix) <- colnames(corMatrix)
    R.y <- corMatrix[-resp.col, resp.col]
    R.x <- corMatrix[-resp.col, -resp.col]
-   if (!colinearity) {
+   if (!collinearity) {
       B <- solve(R.x, R.y)
       path <- sweep(R.x, 2, B, FUN = "*")
       R2 <- B %*% R.y
@@ -18,20 +18,11 @@ function(corMatrix, resp.col, colinearity = FALSE)
       eigval <- eigen(R.x)$values
       cn <- eigval[1] / eigval[nrow(R.x)]
       deter <- det(R.x)
-      cat("\n          Path Analysis \n",
-          "\nDirect (diagonal) and indirect (off-diagonal) effects \n")
-      print(path)
-      cat("--- \nR-squared:", R2, 
-         "\nResidual effect:", res,
-         "\nk-value (for colinearity):", k, "\n")
-      cat("\n          Colinearity diagnostics \n")
-      cat("\nVIF: ", vif,
-          "\nCondition number: ", cn,
-          "\nDeterminant of X'X: ", deter, "\n")
       out <- list(coef = path, Rsq = R2,
-         ResidualEffect = res, VIF = vif, CN = cn)
+         ResidualEffect = res, k.value = k, 
+         VIF = vif, CN = cn, det = deter)
       class(out) <- "pathanalysis"
-      invisible(out)
+      return(out)
    } else {
       mB <- matrix(0, 100, nrow(R.x))
       vec.k <- seq(0, 1, length.out = 100)
@@ -82,8 +73,8 @@ function(corMatrix, resp.col, colinearity = FALSE)
          print(path)
          cat("--- \nR-squared:", R2, 
             "\nResidual effect:", res,
-            "\nk-value (for colinearity):", k, "\n")
-         cat("\n          Colinearity diagnostics \n")
+            "\nk-value (for collinearity):", k, "\n")
+         cat("\n          Collinearity diagnostics \n")
          cat("\nVIF: ", vif,
             "\nCondition number: ", cn,
             "\nDeterminant of (X'X + Ik): ", deter, "\n")
@@ -97,3 +88,22 @@ function(corMatrix, resp.col, colinearity = FALSE)
       rp.button(panel, title = "Run", action = f.fit)
    }
 }
+
+
+# -------------------------------------------
+# print method
+print.pathanalysis <- 
+function (x, digits = 4L, quote = TRUE, ...) 
+{
+   cat("\n          Path Analysis \n",
+       "\nDirect (diagonal) and indirect (off-diagonal) effects \n")
+   print(x$coef)
+   cat("--- \nR-squared:", x$Rsq, 
+      "\nResidual effect:", x$ResidualEffect,
+      "\nk-value (for collinearity):", x$k.value, "\n")
+   cat("\n          Collinearity diagnostics \n")
+   cat("\nVIF: ", x$VIF,
+       "\nCondition number: ", x$CN,
+       "\nDeterminant of X'X: ", x$det, "\n")
+   invisible(x)
+}
